/**
 * Configure your Gatsby site with this file.
 *
 * See: https://www.gatsbyjs.com/docs/reference/config-files/gatsby-config/
 */
const path = require('path');

/**
 * @type {import('gatsby').GatsbyConfig}
 */
module.exports = themeConfig => {
  const defaultThemeConfig = {
    useLegacyUrls: false
  };

  return ({
    siteMetadata: {
      title: 'platformOS DocsKit',
      description: 'DocsKit',
      author: 'platformOS',
      themeConfig: {
        ...defaultThemeConfig,
        ...themeConfig
      }
    },
    plugins: [
      'gatsby-plugin-postcss',
      'gatsby-plugin-image',
      {
        resolve: 'gatsby-plugin-alias-imports',
        options: {
          alias: {
            '@partials': 'partials',
            '@components': path.join(__dirname, './src/components')
          },
          extensions: ['.mdx']
        }
      },
      {
        resolve: 'gatsby-plugin-mdx',
        options: {
          extensions: ['.mdx', '.md'],
          gatsbyRemarkPlugins: [
            {
              resolve: 'gatsby-remark-images',
              options: {
                maxWidth: 704,
                disableBgImageOnAlpha: true,
                linkImagesToOriginal: false,
                backgroundColor: 'transparent'
              }
            },
            'gatsby-remark-autolink-headers',
            'gatsby-remark-embed-video',
            'gatsby-remark-responsive-iframe',
            'gatsby-remark-external-links',
            {
              resolve: `gatsby-remark-prismjs`,
              options: {
                // Class prefix for <pre> tags containing syntax highlighting;
                // defaults to 'language-' (e.g. <pre class="language-js">).
                // If your site loads Prism into the browser at runtime,
                // (e.g. for use with libraries like react-live),
                // you may use this to prevent Prism from re-processing syntax.
                // This is an uncommon use-case though;
                // If you're unsure, it's best to use the default value.
                classPrefix: "language-",
                // This is used to allow setting a language for inline code
                // (i.e. single backticks) by creating a separator.
                // This separator is a string and will do no white-space
                // stripping.
                // A suggested value for English speakers is the non-ascii
                // character '›'.
                inlineCodeMarker: null,
                // This lets you set up language aliases.  For example,
                // setting this to '{ sh: "bash" }' will let you use
                // the language "sh" which will highlight using the
                // bash highlighter.
                aliases: {},
                // This toggles the display of line numbers globally alongside the code.
                // To use it, add the following line in gatsby-browser.js
                // right after importing the prism color scheme:
                //  require("prismjs/plugins/line-numbers/prism-line-numbers.css")
                // Defaults to false.
                // If you wish to only show line numbers on certain code blocks,
                // leave false and use the {numberLines: true} syntax below
                showLineNumbers: false,
                // If setting this to true, the parser won't handle and highlight inline
                // code used in markdown i.e. single backtick code like `this`.
                noInlineHighlight: false,
                // This adds a new language definition to Prism or extend an already
                // existing language definition. More details on this option can be
                // found under the header "Add new language definition or extend an
                // existing language" below.
                languageExtensions: [],
                // Customize the prompt used in shell output
                // Values below are default
                prompt: {
                  user: "root",
                  host: "localhost",
                  global: false,
                },
                // By default the HTML entities <>&'" are escaped.
                // Add additional HTML escapes by providing a mapping
                // of HTML entities and their escape value IE: { '}': '&#123;' }
                escapeEntities: {},
              },
            }
          ]
        }
      },
      'gatsby-plugin-mdx-source-name',
      {
        resolve: 'gatsby-source-filesystem',
        options: {
          path: 'docs',
          name: 'content'
        }
      },
      {
        resolve: 'gatsby-source-filesystem',
        options: {
          path: 'partials',
          name: 'partials'
        }
      },
      'gatsby-transformer-sharp',
      'gatsby-plugin-sharp',
    ],
  });
};
