import { useStaticQuery, graphql } from 'gatsby'
import { generateNavigationTree } from '../utils/createRecursiveMenu';

function getLastSegment(url) {
  const segments = url.split('/');

  if (segments[segments.length - 1] === 'index.mdx') {
    if (segments.length > 1) {
      return `${segments[segments.length - 2]}/${segments[segments.length - 1]}`;
    }
  }

  return segments[segments.length - 1];
}

export const useNavigation = () => {
  const result = useStaticQuery(graphql`
    query {
      allMdx(filter: {fields: {source: {eq: "content"}}}) {
        edges {
          node {
            fields {
              slug
              title
            }
            internal {
              contentFilePath
            }
          }
        }
      }
    }
  `);

  const routes = result.allMdx.edges.map(({ node }) => ({ ...node.fields, fileName: getLastSegment(node.internal.contentFilePath) }));
  const treeData = generateNavigationTree(routes);

  return treeData;
};
