import * as React from 'react';
import { graphql } from 'gatsby';
import { MDXProvider } from '@mdx-js/react';
import Layout from '@components/layout';
import Seo from '@components/seo';
import Hero from '@components/hero';
import Button from '@components/button';
import Grid from '@components/grid';
import Card from '@components/card';
import Message from '@components/message';
import Heading from '@components/heading';
import ThemeProvider from '../theme/theme-provider';

export default function DocsTemplate({ data, children, location }) {
  const { mdx } = data;
  const mdxComponents = {
    Hero,
    Button,
    Grid,
    Card,
    Message,
    h1: (props) => (<Heading level="1" {...props} />),
    h2: (props) => (<Heading level="2" {...props} />),
    h3: (props) => (<Heading level="3" {...props} />),
    h4: (props) => (<Heading level="4" {...props} />),
    h5: (props) => (<Heading level="5" {...props} />)
  };

  return (
    <Layout location={location} currentSlug={mdx.frontmatter.slug}>
      <div className="prose max-w-none prose-a:text-interactive-text">
        <MDXProvider components={mdxComponents}>{children}</MDXProvider>
      </div>
    </Layout>
  );
}

export const Head = ({ data }) => {
  const { mdx } = data;
  return (
    <>
      <Seo title={mdx.frontmatter.title} description={mdx.frontmatter.description} />
      <ThemeProvider />
    </>
  );
};

export const pageQuery = graphql`
  query($id: String!) {
    mdx(fields: { id: { eq: $id } }) {
      body
      frontmatter {
        title
        description
        slug
      }
    }
  }
`;
