export const sortNavigationItems = items => {
  const result = [...items].sort((a, b) => {
    if (a.slug === '/') return -1;
    if (b.slug === '/') return 1;
    return a.fileName.localeCompare(b.fileName);
  });

  for(let i = 0; i < items.length; i++) {
    if (items[i].children && items[i].children.length) {
      items[i].children = sortNavigationItems(items[i].children);
    }
  }
  return result;
};

export const generateNavigationTree = (items) => {
  const nodes = {};

  // create nodes object
  items.forEach(item => {
    const slug = item.slug.replace(/\/index.html$/, '');
    nodes[slug] = {
      slug: item.slug,
      title: item.title,
      fileName: item.fileName,
      children: []
    };
  });

  // build tree
  const tree = [];
  items.forEach(item => {
    const slug = item.slug.replace(/\/index.html$/, '');
    const node = nodes[slug];
    const parentSlug = getParentSlug(slug);

    if (parentSlug) {
      const parentNode = nodes[parentSlug];
      parentNode.children.push(node);
    } else {
      tree.push(node);
    }
  });

  // sort by fileName
  const result = sortNavigationItems(tree);

  return result;

  function getParentSlug(slug) {
    const parts = slug.split('/').filter(Boolean);
    return parts.length > 1 ? `/${parts.slice(0, -1).join('/')}` : null;
  }
}
